@@ -5,5 +5,5 @@
 class BaseSmsClient:
 
     @classmethod
-    def send(cls, number: str, text: str):
+    def send(cls, number: str, text: str, **kwargs):
         raise NotImplementedError
